import React, { FC } from 'react';
import ModalNative from 'react-native-modal';
import { View } from 'react-native';
import { AreaWrapper } from '../areaWrapper';
import { getThemeColorByDefaultColor } from '../../../../utils';

interface Props {
  modalHeight?: string | number;
  children: JSX.Element | JSX.Element[]
  isVisible: boolean;
  onModalHide: () => void;
}

export const BottomSheetWrapper: FC<Props> = ({
  modalHeight = '50%',
  children,
  isVisible,
  onModalHide,
}) => {
  return (
    <AreaWrapper topColor={'#02020299'} barStyle={'light-content'}>
      <ModalNative
        backdropColor={getThemeColorByDefaultColor('text', 'extraDark')}
        backdropOpacity={0}
        isVisible={isVisible}
        onSwipeComplete={onModalHide}
        onBackdropPress={onModalHide}
        useNativeDriverForBackdrop
        swipeDirection={['down']}
        propagateSwipe={true}
        style={{ margin: 0, justifyContent: 'flex-end' }}
      >
        <View style={{ height: modalHeight }}>
          {children}
        </View>
      </ModalNative>
    </AreaWrapper>
  );
};
